pub struct VideoIntelligenceService { /* private fields */ }Expand description
Implements a client for the Cloud Video Intelligence API.
Example
use google_cloud_lro::Poller;
async fn sample(
) -> anyhow::Result<()> {
let client = VideoIntelligenceService::builder().build().await?;
let response = client.annotate_video()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Service Description
Service that implements the Video Intelligence API.
Configuration
To configure VideoIntelligenceService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://videointelligence.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
VideoIntelligenceService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap VideoIntelligenceService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl VideoIntelligenceService
impl VideoIntelligenceService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for VideoIntelligenceService.
let client = VideoIntelligenceService::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: VideoIntelligenceService + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: VideoIntelligenceService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn annotate_video(&self) -> AnnotateVideo
pub fn annotate_video(&self) -> AnnotateVideo
Performs asynchronous video annotation. Progress and results can be
retrieved through the google.longrunning.Operations interface.
Operation.metadata contains AnnotateVideoProgress (progress).
Operation.response contains AnnotateVideoResponse (results).
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_videointelligence_v1::Result;
async fn sample(
client: &VideoIntelligenceService
) -> Result<()> {
let response = client.annotate_video()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_videointelligence_v1::Result;
async fn sample(
client: &VideoIntelligenceService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_videointelligence_v1::Result;
async fn sample(
client: &VideoIntelligenceService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_videointelligence_v1::Result;
async fn sample(
client: &VideoIntelligenceService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_videointelligence_v1::Result;
async fn sample(
client: &VideoIntelligenceService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for VideoIntelligenceService
impl Clone for VideoIntelligenceService
Sourcefn clone(&self) -> VideoIntelligenceService
fn clone(&self) -> VideoIntelligenceService
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for VideoIntelligenceService
impl !UnwindSafe for VideoIntelligenceService
impl Freeze for VideoIntelligenceService
impl Send for VideoIntelligenceService
impl Sync for VideoIntelligenceService
impl Unpin for VideoIntelligenceService
impl UnsafeUnpin for VideoIntelligenceService