#[non_exhaustive]pub enum Feature {
Unspecified,
LabelDetection,
ShotChangeDetection,
ExplicitContentDetection,
FaceDetection,
SpeechTranscription,
TextDetection,
ObjectTracking,
LogoRecognition,
PersonDetection,
UnknownValue(UnknownValue),
}Expand description
Video annotation feature.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Unspecified.
LabelDetection
Label detection. Detect objects, such as dog or flower.
ShotChangeDetection
Shot change detection.
ExplicitContentDetection
Explicit content detection.
FaceDetection
Human face detection.
SpeechTranscription
Speech transcription.
TextDetection
OCR text detection and tracking.
ObjectTracking
Object detection and tracking.
LogoRecognition
Logo detection, tracking, and recognition.
PersonDetection
Person detection.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Feature::value or Feature::name.
Implementations