#[non_exhaustive]pub struct ExplicitContentAnnotation {
pub frames: Vec<ExplicitContentFrame>,
pub version: String,
/* private fields */
}Expand description
Explicit content annotation (based on per-frame visual signals only). If no explicit content has been detected in a frame, no annotations are present for that frame.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.frames: Vec<ExplicitContentFrame>All video frames where explicit content was detected.
version: StringFeature version.
Implementations
Sourceimpl ExplicitContentAnnotation
impl ExplicitContentAnnotation
Sourcepub fn set_frames<T, V>(self, v: T) -> Self
pub fn set_frames<T, V>(self, v: T) -> Self