#[non_exhaustive]pub struct ExplicitContentFrame {
pub time_offset: Option<Duration>,
pub pornography_likelihood: Likelihood,
/* private fields */
}Expand description
Video frame level annotation results for explicit content.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.time_offset: Option<Duration>Time-offset, relative to the beginning of the video, corresponding to the video frame for this location.
pornography_likelihood: LikelihoodLikelihood of the pornography content..
Implementations
Sourceimpl ExplicitContentFrame
impl ExplicitContentFrame
Sourcepub fn set_time_offset<T>(self, v: T) -> Self
pub fn set_time_offset<T>(self, v: T) -> Self
Sets the value of time_offset.
Example
ⓘ
use wkt::Duration;
let x = ExplicitContentFrame::new().set_time_offset(Duration::default()/* use setters */);Sourcepub fn set_or_clear_time_offset<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_time_offset<T>(self, v: Option<T>) -> Self
Sets or clears the value of time_offset.
Example
ⓘ
use wkt::Duration;
let x = ExplicitContentFrame::new().set_or_clear_time_offset(Some(Duration::default()/* use setters */));
let x = ExplicitContentFrame::new().set_or_clear_time_offset(None::<Duration>);Sourcepub fn set_pornography_likelihood<T: Into<Likelihood>>(self, v: T) -> Self
pub fn set_pornography_likelihood<T: Into<Likelihood>>(self, v: T) -> Self
Sets the value of pornography_likelihood.
Example
ⓘ
use google_cloud_videointelligence_v1::model::Likelihood;
let x0 = ExplicitContentFrame::new().set_pornography_likelihood(Likelihood::VeryUnlikely);
let x1 = ExplicitContentFrame::new().set_pornography_likelihood(Likelihood::Unlikely);
let x2 = ExplicitContentFrame::new().set_pornography_likelihood(Likelihood::Possible);Trait Implementations
Sourceimpl Clone for ExplicitContentFrame
impl Clone for ExplicitContentFrame
Sourcefn clone(&self) -> ExplicitContentFrame
fn clone(&self) -> ExplicitContentFrame
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExplicitContentFrame
impl Debug for ExplicitContentFrame
Sourceimpl Default for ExplicitContentFrame
impl Default for ExplicitContentFrame
Sourcefn default() -> ExplicitContentFrame
fn default() -> ExplicitContentFrame
Returns the “default value” for a type. Read more
Sourceimpl Message for ExplicitContentFrame
impl Message for ExplicitContentFrame
Sourceimpl PartialEq for ExplicitContentFrame
impl PartialEq for ExplicitContentFrame
Sourcefn eq(&self, other: &ExplicitContentFrame) -> bool
fn eq(&self, other: &ExplicitContentFrame) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExplicitContentFrame