#[non_exhaustive]pub struct FaceDetectionConfig {
pub model: String,
pub include_bounding_boxes: bool,
pub include_attributes: bool,
/* private fields */
}Expand description
Config for FACE_DETECTION.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.model: StringModel to use for face detection. Supported values: “builtin/stable” (the default if unset) and “builtin/latest”.
include_bounding_boxes: boolWhether bounding boxes are included in the face annotation output.
include_attributes: boolWhether to enable face attributes detection, such as glasses, dark_glasses, mouth_open etc. Ignored if ‘include_bounding_boxes’ is set to false.
Implementations
Sourceimpl FaceDetectionConfig
impl FaceDetectionConfig
Sourcepub fn set_include_bounding_boxes<T: Into<bool>>(self, v: T) -> Self
pub fn set_include_bounding_boxes<T: Into<bool>>(self, v: T) -> Self
Sets the value of include_bounding_boxes.
Example
ⓘ
let x = FaceDetectionConfig::new().set_include_bounding_boxes(true);Sourcepub fn set_include_attributes<T: Into<bool>>(self, v: T) -> Self
pub fn set_include_attributes<T: Into<bool>>(self, v: T) -> Self
Sets the value of include_attributes.
Example
ⓘ
let x = FaceDetectionConfig::new().set_include_attributes(true);Trait Implementations
Sourceimpl Clone for FaceDetectionConfig
impl Clone for FaceDetectionConfig
Sourcefn clone(&self) -> FaceDetectionConfig
fn clone(&self) -> FaceDetectionConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FaceDetectionConfig
impl Debug for FaceDetectionConfig
Sourceimpl Default for FaceDetectionConfig
impl Default for FaceDetectionConfig
Sourcefn default() -> FaceDetectionConfig
fn default() -> FaceDetectionConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for FaceDetectionConfig
impl Message for FaceDetectionConfig
Sourceimpl PartialEq for FaceDetectionConfig
impl PartialEq for FaceDetectionConfig
Sourcefn eq(&self, other: &FaceDetectionConfig) -> bool
fn eq(&self, other: &FaceDetectionConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FaceDetectionConfig