#[non_exhaustive]pub struct FaceFrame {
pub normalized_bounding_boxes: Vec<NormalizedBoundingBox>,
pub time_offset: Option<Duration>,
/* private fields */
}๐Deprecated
Deprecated. No effect.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.normalized_bounding_boxes: Vec<NormalizedBoundingBox>๐Deprecated
Normalized Bounding boxes in a frame. There can be more than one boxes if the same face is detected in multiple locations within the current frame.
time_offset: Option<Duration>๐Deprecated
Time-offset, relative to the beginning of the video, corresponding to the video frame for this location.
Implementations
Sourceimpl FaceFrame
impl FaceFrame
Sourcepub fn set_normalized_bounding_boxes<T, V>(self, v: T) -> Self
pub fn set_normalized_bounding_boxes<T, V>(self, v: T) -> Self
Sets the value of normalized_bounding_boxes.
Example
โ
use google_cloud_videointelligence_v1::model::NormalizedBoundingBox;
let x = FaceFrame::new()
.set_normalized_bounding_boxes([
NormalizedBoundingBox::default()/* use setters */,
NormalizedBoundingBox::default()/* use (different) setters */,
]);Sourcepub fn set_time_offset<T>(self, v: T) -> Self
pub fn set_time_offset<T>(self, v: T) -> Self
Sets the value of time_offset.
Example
โ
use wkt::Duration;
let x = FaceFrame::new().set_time_offset(Duration::default()/* use setters */);Sourcepub fn set_or_clear_time_offset<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_time_offset<T>(self, v: Option<T>) -> Self
Sets or clears the value of time_offset.
Example
โ
use wkt::Duration;
let x = FaceFrame::new().set_or_clear_time_offset(Some(Duration::default()/* use setters */));
let x = FaceFrame::new().set_or_clear_time_offset(None::<Duration>);Trait Implementations
Sourceimpl PartialEq for FaceFrame
impl PartialEq for FaceFrame
impl StructuralPartialEq for FaceFrame