LabelAnnotation

Struct LabelAnnotation 

#[non_exhaustive]
pub struct LabelAnnotation { pub entity: Option<Entity>, pub category_entities: Vec<Entity>, pub segments: Vec<LabelSegment>, pub frames: Vec<LabelFrame>, pub version: String, /* private fields */ }
Label annotation.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
entity: Option<Entity>

Detected entity.

category_entities: Vec<Entity>

Common categories for the detected entity. For example, when the label is Terrier, the category is likely dog. And in some cases there might be more than one categories e.g., Terrier could also be a pet.

segments: Vec<LabelSegment>

All video segments where a label was detected.

frames: Vec<LabelFrame>

All video frames where a label was detected.

version: String

Feature version.

Implementations

Source

impl LabelAnnotation

pub fn new() -> Self

Creates a new default instance.

pub fn set_entity<T>(self, v: T) -> Self
where T: Into<Entity>,

Sets the value of entity.

Example
use google_cloud_videointelligence_v1::model::Entity;
let x = LabelAnnotation::new().set_entity(Entity::default()/* use setters */);
pub fn set_or_clear_entity<T>(self, v: Option<T>) -> Self
where T: Into<Entity>,

Sets or clears the value of entity.

Example
use google_cloud_videointelligence_v1::model::Entity;
let x = LabelAnnotation::new().set_or_clear_entity(Some(Entity::default()/* use setters */));
let x = LabelAnnotation::new().set_or_clear_entity(None::<Entity>);
pub fn set_category_entities<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Entity>,

Sets the value of category_entities.

Example
use google_cloud_videointelligence_v1::model::Entity;
let x = LabelAnnotation::new()
    .set_category_entities([
        Entity::default()/* use setters */,
        Entity::default()/* use (different) setters */,
    ]);
pub fn set_segments<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<LabelSegment>,

Sets the value of segments.

Example
use google_cloud_videointelligence_v1::model::LabelSegment;
let x = LabelAnnotation::new()
    .set_segments([
        LabelSegment::default()/* use setters */,
        LabelSegment::default()/* use (different) setters */,
    ]);
pub fn set_frames<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<LabelFrame>,

Sets the value of frames.

Example
use google_cloud_videointelligence_v1::model::LabelFrame;
let x = LabelAnnotation::new()
    .set_frames([
        LabelFrame::default()/* use setters */,
        LabelFrame::default()/* use (different) setters */,
    ]);
pub fn set_version<T: Into<String>>(self, v: T) -> Self

Sets the value of version.

Example
let x = LabelAnnotation::new().set_version("example");