#[non_exhaustive]pub struct NormalizedBoundingPoly {
pub vertices: Vec<NormalizedVertex>,
/* private fields */
}Expand description
Normalized bounding polygon for text (that might not be aligned with axis). Contains list of the corner points in clockwise order starting from top-left corner. For example, for a rectangular bounding box: When the text is horizontal it might look like: 0––1 | | 3––2
When it’s clockwise rotated 180 degrees around the top-left corner it becomes: 2––3 | | 1––0
and the vertex order will still be (0, 1, 2, 3). Note that values can be less than 0, or greater than 1 due to trignometric calculations for location of the box.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.vertices: Vec<NormalizedVertex>Normalized vertices of the bounding polygon.
Implementations
Sourceimpl NormalizedBoundingPoly
impl NormalizedBoundingPoly
Sourcepub fn set_vertices<T, V>(self, v: T) -> Self
pub fn set_vertices<T, V>(self, v: T) -> Self