#[non_exhaustive]pub struct ObjectTrackingFrame {
pub normalized_bounding_box: Option<NormalizedBoundingBox>,
pub time_offset: Option<Duration>,
/* private fields */
}Expand description
Video frame level annotations for object detection and tracking. This field stores per frame location, time offset, and confidence.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.normalized_bounding_box: Option<NormalizedBoundingBox>The normalized bounding box location of this object track for the frame.
time_offset: Option<Duration>The timestamp of the frame in microseconds.
Implementations
Sourceimpl ObjectTrackingFrame
impl ObjectTrackingFrame
Sourcepub fn set_normalized_bounding_box<T>(self, v: T) -> Selfwhere
T: Into<NormalizedBoundingBox>,
pub fn set_normalized_bounding_box<T>(self, v: T) -> Selfwhere
T: Into<NormalizedBoundingBox>,
Sets the value of normalized_bounding_box.
Example
ⓘ
use google_cloud_videointelligence_v1::model::NormalizedBoundingBox;
let x = ObjectTrackingFrame::new().set_normalized_bounding_box(NormalizedBoundingBox::default()/* use setters */);Sourcepub fn set_or_clear_normalized_bounding_box<T>(self, v: Option<T>) -> Selfwhere
T: Into<NormalizedBoundingBox>,
pub fn set_or_clear_normalized_bounding_box<T>(self, v: Option<T>) -> Selfwhere
T: Into<NormalizedBoundingBox>,
Sets or clears the value of normalized_bounding_box.
Example
ⓘ
use google_cloud_videointelligence_v1::model::NormalizedBoundingBox;
let x = ObjectTrackingFrame::new().set_or_clear_normalized_bounding_box(Some(NormalizedBoundingBox::default()/* use setters */));
let x = ObjectTrackingFrame::new().set_or_clear_normalized_bounding_box(None::<NormalizedBoundingBox>);Sourcepub fn set_time_offset<T>(self, v: T) -> Self
pub fn set_time_offset<T>(self, v: T) -> Self
Sets the value of time_offset.
Example
ⓘ
use wkt::Duration;
let x = ObjectTrackingFrame::new().set_time_offset(Duration::default()/* use setters */);Sourcepub fn set_or_clear_time_offset<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_time_offset<T>(self, v: Option<T>) -> Self
Sets or clears the value of time_offset.
Example
ⓘ
use wkt::Duration;
let x = ObjectTrackingFrame::new().set_or_clear_time_offset(Some(Duration::default()/* use setters */));
let x = ObjectTrackingFrame::new().set_or_clear_time_offset(None::<Duration>);Trait Implementations
Sourceimpl Clone for ObjectTrackingFrame
impl Clone for ObjectTrackingFrame
Sourcefn clone(&self) -> ObjectTrackingFrame
fn clone(&self) -> ObjectTrackingFrame
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObjectTrackingFrame
impl Debug for ObjectTrackingFrame
Sourceimpl Default for ObjectTrackingFrame
impl Default for ObjectTrackingFrame
Sourcefn default() -> ObjectTrackingFrame
fn default() -> ObjectTrackingFrame
Returns the “default value” for a type. Read more
Sourceimpl Message for ObjectTrackingFrame
impl Message for ObjectTrackingFrame
Sourceimpl PartialEq for ObjectTrackingFrame
impl PartialEq for ObjectTrackingFrame
Sourcefn eq(&self, other: &ObjectTrackingFrame) -> bool
fn eq(&self, other: &ObjectTrackingFrame) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ObjectTrackingFrame