#[non_exhaustive]pub struct TextDetectionConfig {
pub language_hints: Vec<String>,
pub model: String,
/* private fields */
}Expand description
Config for TEXT_DETECTION.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.language_hints: Vec<String>Language hint can be specified if the language to be detected is known a priori. It can increase the accuracy of the detection. Language hint must be language code in BCP-47 format.
Automatic language detection is performed if no hint is provided.
model: StringModel to use for text detection. Supported values: “builtin/stable” (the default if unset) and “builtin/latest”.
Implementations
Sourceimpl TextDetectionConfig
impl TextDetectionConfig
Sourcepub fn set_language_hints<T, V>(self, v: T) -> Self
pub fn set_language_hints<T, V>(self, v: T) -> Self
Sets the value of language_hints.
Example
ⓘ
let x = TextDetectionConfig::new().set_language_hints(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for TextDetectionConfig
impl Clone for TextDetectionConfig
Sourcefn clone(&self) -> TextDetectionConfig
fn clone(&self) -> TextDetectionConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TextDetectionConfig
impl Debug for TextDetectionConfig
Sourceimpl Default for TextDetectionConfig
impl Default for TextDetectionConfig
Sourcefn default() -> TextDetectionConfig
fn default() -> TextDetectionConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for TextDetectionConfig
impl Message for TextDetectionConfig
Sourceimpl PartialEq for TextDetectionConfig
impl PartialEq for TextDetectionConfig
Sourcefn eq(&self, other: &TextDetectionConfig) -> bool
fn eq(&self, other: &TextDetectionConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TextDetectionConfig