#[non_exhaustive]pub struct TextFrame {
pub rotated_bounding_box: Option<NormalizedBoundingPoly>,
pub time_offset: Option<Duration>,
/* private fields */
}Expand description
Video frame level annotation results for text annotation (OCR). Contains information regarding timestamp and bounding box locations for the frames containing detected OCR text snippets.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rotated_bounding_box: Option<NormalizedBoundingPoly>Bounding polygon of the detected text for this frame.
time_offset: Option<Duration>Timestamp of this frame.
Implementations
Sourceimpl TextFrame
impl TextFrame
Sourcepub fn set_rotated_bounding_box<T>(self, v: T) -> Selfwhere
T: Into<NormalizedBoundingPoly>,
pub fn set_rotated_bounding_box<T>(self, v: T) -> Selfwhere
T: Into<NormalizedBoundingPoly>,
Sets the value of rotated_bounding_box.
Example
ⓘ
use google_cloud_videointelligence_v1::model::NormalizedBoundingPoly;
let x = TextFrame::new().set_rotated_bounding_box(NormalizedBoundingPoly::default()/* use setters */);Sourcepub fn set_or_clear_rotated_bounding_box<T>(self, v: Option<T>) -> Selfwhere
T: Into<NormalizedBoundingPoly>,
pub fn set_or_clear_rotated_bounding_box<T>(self, v: Option<T>) -> Selfwhere
T: Into<NormalizedBoundingPoly>,
Sets or clears the value of rotated_bounding_box.
Example
ⓘ
use google_cloud_videointelligence_v1::model::NormalizedBoundingPoly;
let x = TextFrame::new().set_or_clear_rotated_bounding_box(Some(NormalizedBoundingPoly::default()/* use setters */));
let x = TextFrame::new().set_or_clear_rotated_bounding_box(None::<NormalizedBoundingPoly>);Sourcepub fn set_time_offset<T>(self, v: T) -> Self
pub fn set_time_offset<T>(self, v: T) -> Self
Sets the value of time_offset.
Example
ⓘ
use wkt::Duration;
let x = TextFrame::new().set_time_offset(Duration::default()/* use setters */);Sourcepub fn set_or_clear_time_offset<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_time_offset<T>(self, v: Option<T>) -> Self
Sets or clears the value of time_offset.
Example
ⓘ
use wkt::Duration;
let x = TextFrame::new().set_or_clear_time_offset(Some(Duration::default()/* use setters */));
let x = TextFrame::new().set_or_clear_time_offset(None::<Duration>);Trait Implementations
impl StructuralPartialEq for TextFrame