#[non_exhaustive]pub struct VideoAnnotationProgress {
pub input_uri: String,
pub progress_percent: i32,
pub start_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub feature: Feature,
pub segment: Option<VideoSegment>,
/* private fields */
}Expand description
Annotation progress for a single video.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.input_uri: StringVideo file location in Cloud Storage.
progress_percent: i32Approximate percentage processed thus far. Guaranteed to be 100 when fully processed.
start_time: Option<Timestamp>Time when the request was received.
update_time: Option<Timestamp>Time of the most recent update.
feature: FeatureSpecifies which feature is being tracked if the request contains more than one feature.
segment: Option<VideoSegment>Specifies which segment is being tracked if the request contains more than one segment.
Implementations
Sourceimpl VideoAnnotationProgress
impl VideoAnnotationProgress
Sourcepub fn set_input_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_input_uri<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_progress_percent<T: Into<i32>>(self, v: T) -> Self
pub fn set_progress_percent<T: Into<i32>>(self, v: T) -> Self
Sets the value of progress_percent.
Example
ⓘ
let x = VideoAnnotationProgress::new().set_progress_percent(42);Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
ⓘ
use wkt::Timestamp;
let x = VideoAnnotationProgress::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
ⓘ
use wkt::Timestamp;
let x = VideoAnnotationProgress::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = VideoAnnotationProgress::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = VideoAnnotationProgress::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = VideoAnnotationProgress::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = VideoAnnotationProgress::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_feature<T: Into<Feature>>(self, v: T) -> Self
pub fn set_feature<T: Into<Feature>>(self, v: T) -> Self
Sets the value of feature.
Example
ⓘ
use google_cloud_videointelligence_v1::model::Feature;
let x0 = VideoAnnotationProgress::new().set_feature(Feature::LabelDetection);
let x1 = VideoAnnotationProgress::new().set_feature(Feature::ShotChangeDetection);
let x2 = VideoAnnotationProgress::new().set_feature(Feature::ExplicitContentDetection);Sourcepub fn set_segment<T>(self, v: T) -> Selfwhere
T: Into<VideoSegment>,
pub fn set_segment<T>(self, v: T) -> Selfwhere
T: Into<VideoSegment>,
Sourcepub fn set_or_clear_segment<T>(self, v: Option<T>) -> Selfwhere
T: Into<VideoSegment>,
pub fn set_or_clear_segment<T>(self, v: Option<T>) -> Selfwhere
T: Into<VideoSegment>,